<?php
/**
 * Created by JetBrains PhpStorm.
 * User: jorgefonseca
 * Date: 28/11/13
 * Time: 10:17
 * To change this template use File | Settings | File Templates.
 */

namespace Folha\Facade;
require_once __DIR__.'/../Util/macros.php';
use Geral\Util\Ambiente;

class Calculo {

    /**
     * Traz os parametros, chama o calculo e demonstra o resultado na tela quando for simulacao.
     *
     * @param string  $tipo_calculo     Tipo de calculo.
     * @param string  $tp_processamento Tipo de processamento.
     * @param integer $nrFormulario     Numero do Formulario.
     *
     * @return void
     *
     * @author alessandrobartels -
     *         nataliacesario    - 07/06/2011 - Implementacao do numero da organizacao de trabalho do operador.
     *         alessandrobartels - 04/07/2011 - Retirado nrOrg e cdOperador do parametro. Setados do Ambiente no Logic.
     */
    public static function executaCalculo($tipo_calculo, $tp_processamento, $nrFormulario) {
        // Tempo de execucao deve ser ilimitado.
        set_time_limit(0);
        //tk_disable_result_set_limit();
        // Dados da sessao.

        //Seta valores de gozo de férias (se existir) para o vínculo em questão. Também verifica o não preenchimento de
        //alguns possivelmente obrigatórios. Rafael Pck 25/03/2015.
        \FeriasFacade::persisteGozoFerias($tipo_calculo, $tp_processamento);

        $nrOrg = \Ambiente::getNrorg();
        $cdOperador = \Ambiente::getCdOperador();

        // Define parametros do operador.
        $parametro = new \Parametros($nrOrg, $cdOperador);

        $percorreCalculo = new \PercorreCalculo((int)$tipo_calculo, $tp_processamento, $nrFormulario, $parametro);
        try {
            $resultado = $percorreCalculo->percorre();

            //felipesantos 24/04/2015
            if ($resultado === null) {
                throw new \Exception('Nenhum vinculo encontrado');
            }
            elseif ($resultado['ABORT'] === true) {
                $message = ucwords(strtolower($tp_processamento)).' não finalizado com erros.<br>';
                foreach ($resultado['MENSAGENS'] as $mensagem) {
                    //$message .= '<br>'.$mensagem['MENSAGEM'];
                    $message .= strpos($message, $mensagem['MENSAGEM']) ? null : '<br> - '.$mensagem['MENSAGEM'];
                }
                tk_warning($message);
            }
            elseif ($resultado['ERRO'] === false) {
                self::exibe($resultado['DEMONSTRATIVO'], 'RESULTADO');
                tk_message(ucwords(strtolower($tp_processamento)).' finalizado sem erros.', 'success');
            }
            else {
                $params = array(
                    'NRCALCULOFOLHA' => $resultado['CALCULO'],
                    'DSORDEM' => tk_get_field_value('DSORDEM'),
                    'DSINICIO' => tk_get_field_value('DSINICIO'),
                    'DSFIM' => tk_get_field_value('DSFIM')
                );

                $button[] = array(
                    'label' => 'Ok',
                    'method' => "tk_open_window",
                    'params_arr' => array('fpa_msgcalculo', false, $params)
                );

                tk_dialog(ucwords(strtolower($tp_processamento)).' finalizado com advertências.<br>Verifique as mensagens.', $button);
            }
        } catch (\Exception $e) {
            //felipesantos 27/04/2015
            //tk_warning(ucwords(strtolower($tp_processamento)).' finalizado com advertências.');
            //tk_warning($e->getMessage());
            //tk_warning($e->getTraceAsString());
            $msg_except = ucwords(strtolower($tp_processamento)).' finalizado com advertências.';
            $msg_except .= '<br>------------------<br>';
            $msg_except .= $e->getMessage();
            $msg_except .= '<br>------------------<br>';
            $msg_except .= $e->getTraceAsString();
            tk_warning($msg_except);
        }

    }


    public static function exibe(\Demonstrativo $demonstrativo, $nomeCampo) {
        $valor = $demonstrativo->__toString();
        tk_set_field_value($nomeCampo, $valor);
    }

    public static function calculo($tipo_calculo, $tp_processamento, $nrFormulario)
    {
        try {

            if((tk_get_field_value('_STATE') == 'U') || tk_get_field_value('_STATE') == 'I'){
                throw new \Exception('Operação bloqueada. Necessário salvar o formulário antes');
            }


            $yes = array(
                'label' => 'Sim',
                'method' => array("\\Folha\\Facade\\Calculo", "executaCalculo"),
                'params_arr' => array($tipo_calculo, $tp_processamento, $nrFormulario)
            );
            $no = array(
                'label' => 'Não',
            );

            tk_confirm('Deseja efetuar o calculo?', $yes, $no);
        } catch (\Exception $e) {
            tk_message($e->getMessage(), 'error');
        }
    }

}